import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom
} from 'd3';

const svg = select('svg'); 

const width = +svg.attr('width');
const height = +svg.attr('height');

const circleRadius = 8;

const xValue = d => d.mpg;
const yValue = d => d.horsepower;

const xAxisLabel = 'MPG';
const yAxisLabel = 'Horsepower';

const title = 'Cars Horsepower Vs MPG';

const margin = {top: 80, right: 30, bottom: 80, left: 120};
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;

const render = data => {
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
		.nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(15);;
  const yAxisG = g.append('g')
    .call(yAxis)
  	
  yAxisG.select('.domain')
		.remove();
  
  yAxisG.append('text')
  		.text(yAxisLabel)
  			.attr('transform', 'rotate(-90)')
  			.attr('x', -innerHeight / 2)
  			.attr('y', -75)
  			.attr('class', 'axisLabel')
  			.attr('text-anchor', 'middle');
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
    const xAxisG = g.append('g')
      .call(xAxis)
        .attr('transform', `translate(0, ${innerHeight})`);
      
    xAxisG.select('.domain')
        .remove();
  
  	xAxisG.append('text')
  		.text(xAxisLabel)
  			.attr('x', innerWidth / 2)
  			.attr('y', 65)
  			.attr('class', 'axisLabel');
  
  g.append('text')
  	.text(title)
  		.attr('y', -20)
  		.attr('class', 'title');
  	
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
      .attr('cy', d => yScale(yValue(d)));
};

csv('https://vizhub.com/curran/datasets/auto-mpg.csv').then(data => {
  data.forEach(d => {
    d.mpg = +d.mpg;
    d.horsepower = +d.horsepower;
  });
  render(data);
});
